@@ -74,13 +74,13 @@
 #'   \item{component}{character, principle component}
 #'   \item{id}{character, id of this step}
 #' }
-#' 
+#'
 #' ```{r, echo = FALSE, results="asis"}
 #' step <- "step_pca_sparse_bayes"
 #' result <- knitr::knit_child("man/rmd/tunable-args.Rmd")
 #' cat(result)
 #' ```
-#' 
+#'
 #' @template case-weights-not-supported
 #'
 #' @seealso [step_pca_sparse()]
@@ -91,41 +91,43 @@
 #' data(ad_data, package = "modeldata")
 #'
 #' ad_rec <-
-#'   recipe(Class ~ ., data = ad_data) %>%
-#'   step_zv(all_predictors()) %>%
-#'   step_YeoJohnson(all_numeric_predictors()) %>%
-#'   step_normalize(all_numeric_predictors()) %>%
+#'   recipe(Class ~ ., data = ad_data) |>
+#'   step_zv(all_predictors()) |>
+#'   step_YeoJohnson(all_numeric_predictors()) |>
+#'   step_normalize(all_numeric_predictors()) |>
 #'   step_pca_sparse_bayes(
 #'     all_numeric_predictors(),
 #'     prior_mixture_threshold = 0.95,
 #'     prior_slab_dispersion = 0.05,
 #'     num_comp = 3,
 #'     id = "sparse bayesian pca"
-#'   ) %>%
+#'   ) |>
 #'   prep()
 #'
-#' tidy(ad_rec, id = "sparse bayesian pca") %>%
-#'   mutate(value = ifelse(value == 0, NA, value)) %>%
+#' tidy(ad_rec, id = "sparse bayesian pca") |>
+#'   mutate(value = ifelse(value == 0, NA, value)) |>
 #'   ggplot(aes(x = component, y = terms, fill = value)) +
 #'   geom_tile() +
 #'   scale_fill_gradient2() +
 #'   theme(axis.text.y = element_blank())
 #' @export
-step_pca_sparse_bayes <- function(recipe,
-                                  ...,
-                                  role = "predictor",
-                                  trained = FALSE,
-                                  num_comp = 5,
-                                  prior_slab_dispersion = 1.0,
-                                  prior_mixture_threshold = 0.1,
-                                  options = list(),
-                                  res = NULL,
-                                  prefix = "PC",
-                                  keep_original_cols = FALSE,
-                                  skip = FALSE,
-                                  id = rand_id("pca_sparse_bayes")) {
+step_pca_sparse_bayes <- function(
+  recipe,
+  ...,
+  role = "predictor",
+  trained = FALSE,
+  num_comp = 5,
+  prior_slab_dispersion = 1.0,
+  prior_mixture_threshold = 0.1,
+  options = list(),
+  res = NULL,
+  prefix = "PC",
+  keep_original_cols = FALSE,
+  skip = FALSE,
+  id = rand_id("pca_sparse_bayes")
+) {
   check_string(prefix)
-  
+
   add_step(
     recipe,
     step_pca_sparse_bayes_new(
@@ -146,9 +148,20 @@ step_pca_sparse_bayes <- function(recipe,
 }
 
 step_pca_sparse_bayes_new <-
-  function(terms, role, trained, num_comp, prior_slab_dispersion,
-           prior_mixture_threshold, options, res, prefix,
-           keep_original_cols, skip, id) {
+  function(
+    terms,
+    role,
+    trained,
+    num_comp,
+    prior_slab_dispersion,
+    prior_mixture_threshold,
+    options,
+    res,
+    prefix,
+    keep_original_cols,
+    skip,
+    id
+  ) {
     step(
       subclass = "pca_sparse_bayes",
       terms = terms,
@@ -172,10 +185,15 @@ prep.step_pca_sparse_bayes <- function(x, training, info = NULL, ...) {
 
   check_number_whole(x$num_comp, min = 0, arg = "num_comp")
   check_number_decimal(
-    x$prior_slab_dispersion, min = 0, arg = "prior_slab_dispersion"
+    x$prior_slab_dispersion,
+    min = 0,
+    arg = "prior_slab_dispersion"
   )
   check_number_decimal(
-    x$prior_mixture_threshold, min = 0, max = 1, arg = "prior_mixture_threshold"
+    x$prior_mixture_threshold,
+    min = 0,
+    max = 1,
+    arg = "prior_mixture_threshold"
   )
 
   if (length(col_names) > 0) {
@@ -192,7 +210,7 @@ prep.step_pca_sparse_bayes <- function(x, training, info = NULL, ...) {
 
     if (x$num_comp > 0) {
       rlang::check_installed("VBsparsePCA")
-      
+
       cl <-
         rlang::call2(
           "VBsparsePCA",
@@ -236,7 +254,7 @@ bake.step_pca_sparse_bayes <- function(object, new_data, ...) {
   if (all(is.na(object$res))) {
     return(new_data)
   }
-  
+
   pca_vars <- rownames(object$res)
   check_new_data(pca_vars, object, new_data)
 
@@ -247,7 +265,7 @@ bake.step_pca_sparse_bayes <- function(object, new_data, ...) {
   new_data <- vec_cbind(new_data, comps)
 
   new_data <- remove_original_cols(new_data, object, pca_vars)
-  
+
   new_data
 }
 
