@@ -18,10 +18,10 @@ credit_data_test <- rsample::testing(credit_data_split)
 set.seed(2393)
 credit_data_small <- dplyr::sample_n(credit_data_train, 30)
 
-rec_credit <- credit_data_train %>%
-  select(-Status) %>%
-  recipe(~.) %>%
-  step_integer(all_predictors()) %>%
+rec_credit <- credit_data_train |>
+  select(-Status) |>
+  recipe(~.) |>
+  step_integer(all_predictors()) |>
   prep(retain = TRUE)
 
 xgb_credit_train <- xgboost::xgb.DMatrix(
@@ -38,19 +38,22 @@ xgb_credit_test <- xgboost::xgb.DMatrix(
 
 # Data for multi-classification problem testing
 set.seed(42)
-attrition <- attrition %>%
+attrition <- attrition |>
   mutate(EducationField = as.integer(EducationField) - 1)
-attrition_data_split <- rsample::initial_split(attrition, strata = "EducationField")
+attrition_data_split <- rsample::initial_split(
+  attrition,
+  strata = "EducationField"
+)
 attrition_data_train <- rsample::training(attrition_data_split)
 attrition_data_test <- rsample::testing(attrition_data_split)
 
 set.seed(2393)
 attrition_data_small <- dplyr::sample_n(attrition_data_train, 10)
 
-rec_attrition <- attrition_data_train %>%
-  select(-EducationField) %>%
-  recipe(~.) %>%
-  step_integer(all_predictors()) %>%
+rec_attrition <- attrition_data_train |>
+  select(-EducationField) |>
+  recipe(~.) |>
+  step_integer(all_predictors()) |>
   prep(retain = TRUE)
 
 xgb_attrition_train <- xgboost::xgb.DMatrix(
@@ -75,10 +78,10 @@ ames_data_test <- rsample::testing(ames_data_split)
 set.seed(8134)
 ames_data_small <- dplyr::sample_n(ames_data_train, 10)
 
-ames_rec <- ames_data_train %>%
-  select(-Sale_Price) %>%
-  recipe(~.) %>%
-  step_integer(all_predictors()) %>%
+ames_rec <- ames_data_train |>
+  select(-Sale_Price) |>
+  recipe(~.) |>
+  step_integer(all_predictors()) |>
   prep(retain = TRUE)
 
 xgb_ames_train <- xgboost::xgb.DMatrix(
@@ -106,8 +109,8 @@ sim_tr_reg <- sim_data_reg(1000)
 sim_te_reg <- sim_data_reg(100)
 
 test_that("run_xgboost for classification", {
-  skip_on_cran() # because data.table uses all cores by default 
-  
+  skip_on_cran() # because data.table uses all cores by default
+
   xgboost <- embed:::run_xgboost(
     xgb_credit_train,
     xgb_credit_test,
@@ -127,8 +130,8 @@ test_that("run_xgboost for classification", {
 })
 
 test_that("run_xgboost for multi-classification", {
-  skip_on_cran() # because data.table uses all cores by default 
-  
+  skip_on_cran() # because data.table uses all cores by default
+
   xgboost <- embed:::run_xgboost(
     xgb_attrition_train,
     xgb_attrition_test,
@@ -148,8 +151,8 @@ test_that("run_xgboost for multi-classification", {
 })
 
 test_that("run_xgboost for regression", {
-  skip_on_cran() # because data.table uses all cores by default 
-  
+  skip_on_cran() # because data.table uses all cores by default
+
   xgboost <- embed:::run_xgboost(
     xgb_ames_train,
     xgb_ames_test,
@@ -169,8 +172,8 @@ test_that("run_xgboost for regression", {
 })
 
 test_that("xgb_binning for classification", {
-  skip_on_cran() # because data.table uses all cores by default 
-  
+  skip_on_cran() # because data.table uses all cores by default
+
   less_than_3.6 <- function() {
     utils::compareVersion("3.5.3", as.character(getRversion())) >= 0
   }
@@ -210,8 +213,8 @@ test_that("xgb_binning for classification", {
 })
 
 test_that("xgb_binning for multi-classification", {
-  skip_on_cran() # because data.table uses all cores by default 
-  
+  skip_on_cran() # because data.table uses all cores by default
+
   less_than_3.6 <- function() {
     utils::compareVersion("3.5.3", as.character(getRversion())) >= 0
   }
@@ -250,8 +253,8 @@ test_that("xgb_binning for multi-classification", {
 })
 
 test_that("xgb_binning for regression", {
-  skip_on_cran() # because data.table uses all cores by default 
-  
+  skip_on_cran() # because data.table uses all cores by default
+
   less_than_3.6 <- function() {
     utils::compareVersion("3.5.3", as.character(getRversion())) >= 0
   }
@@ -291,12 +294,12 @@ test_that("xgb_binning for regression", {
 })
 
 test_that("step_discretize_xgb for classification", {
-  skip_on_cran() # because data.table uses all cores by default 
-  
+  skip_on_cran() # because data.table uses all cores by default
+
   set.seed(125)
   # General use
   xgb_rec <-
-    recipe(class ~ ., data = sim_tr_cls) %>%
+    recipe(class ~ ., data = sim_tr_cls) |>
     step_discretize_xgb(all_predictors(), outcome = "class")
 
   set.seed(28)
@@ -321,38 +324,40 @@ test_that("step_discretize_xgb for classification", {
 
   # Too few data
   expect_snapshot(error = TRUE, {
-    recipe(class ~ ., data = sim_tr_cls[1:9, ]) %>%
-      step_discretize_xgb(all_predictors(), outcome = "class") %>%
+    recipe(class ~ ., data = sim_tr_cls[1:9, ]) |>
+      step_discretize_xgb(all_predictors(), outcome = "class") |>
       prep()
   })
 
   # No numeric variables present
   predictors_non_numeric <- c(
-    "Status", "Home", "Marital"
+    "Status",
+    "Home",
+    "Marital"
   )
 
-  xgb_rec <- credit_data_train %>%
-    select(one_of(predictors_non_numeric)) %>%
-    recipe(Status ~ .) %>%
-    step_impute_median(all_numeric()) %>%
+  xgb_rec <- credit_data_train |>
+    select(one_of(predictors_non_numeric)) |>
+    recipe(Status ~ .) |>
+    step_impute_median(all_numeric()) |>
     step_discretize_xgb(all_numeric(), outcome = "Status")
 
   # Information about insufficient datapoints for Time predictor
   expect_snapshot({
     set.seed(1)
-    recipe(Status ~ ., data = credit_data_train) %>%
-      step_discretize_xgb(Time, outcome = "Status") %>%
+    recipe(Status ~ ., data = credit_data_train) |>
+      step_discretize_xgb(Time, outcome = "Status") |>
       prep(retain = TRUE)
   })
 })
 
 test_that("step_discretize_xgb for multi-classification", {
-  skip_on_cran() # because data.table uses all cores by default 
-  
+  skip_on_cran() # because data.table uses all cores by default
+
   set.seed(125)
   # General use
   xgb_rec <-
-    recipe(class ~ ., data = sim_tr_mcls) %>%
+    recipe(class ~ ., data = sim_tr_mcls) |>
     step_discretize_xgb(all_predictors(), outcome = "class")
 
   set.seed(28)
@@ -378,30 +383,39 @@ test_that("step_discretize_xgb for multi-classification", {
   # Too few data
   expect_snapshot(
     error = TRUE,
-    recipe(class ~ ., data = sim_tr_mcls[1:9, ]) %>%
-      step_discretize_xgb(all_predictors(), outcome = "class") %>%
+    recipe(class ~ ., data = sim_tr_mcls[1:9, ]) |>
+      step_discretize_xgb(all_predictors(), outcome = "class") |>
       prep()
   )
 
   # No numeric variables present
   predictors_non_numeric <- c(
-    "Attrition", "BusinessTravel", "Department",
-    "Education", "EnvironmentSatisfaction", "Gender",
-    "JobInvolvement", "JobRole", "JobSatisfaction",
-    "MaritalStatus", "OverTime", "PerformanceRating",
-    "RelationshipSatisfaction", "WorkLifeBalance"
+    "Attrition",
+    "BusinessTravel",
+    "Department",
+    "Education",
+    "EnvironmentSatisfaction",
+    "Gender",
+    "JobInvolvement",
+    "JobRole",
+    "JobSatisfaction",
+    "MaritalStatus",
+    "OverTime",
+    "PerformanceRating",
+    "RelationshipSatisfaction",
+    "WorkLifeBalance"
   )
 
-  xgb_rec <- attrition_data_train %>%
-    select(one_of(predictors_non_numeric)) %>%
-    recipe(BusinessTravel ~ .) %>%
-    step_impute_median(all_numeric()) %>%
+  xgb_rec <- attrition_data_train |>
+    select(one_of(predictors_non_numeric)) |>
+    recipe(BusinessTravel ~ .) |>
+    step_impute_median(all_numeric()) |>
     step_discretize_xgb(all_numeric(), outcome = "BusinessTravel")
 })
 
 test_that("step_discretize_xgb for regression", {
-  skip_on_cran() # because data.table uses all cores by default 
-  
+  skip_on_cran() # because data.table uses all cores by default
+
   # Skip on R < 3.6 since the rng is different.
   skip("Needs to determine why random numbers are different")
 
@@ -413,7 +427,7 @@ test_that("step_discretize_xgb for regression", {
   # General use
   set.seed(83834)
   xgb_rec <-
-    recipe(y ~ ., data = sim_tr_reg) %>%
+    recipe(y ~ ., data = sim_tr_reg) |>
     step_discretize_xgb(all_predictors(), outcome = "y")
   tidy_untrained <- tidy(xgb_rec, 1)
 
@@ -461,8 +475,8 @@ test_that("step_discretize_xgb for regression", {
   sim_tr_reg$x <- round(sim_tr_reg$x, 1)
   expect_snapshot({
     xgb_rec <-
-      recipe(y ~ ., data = sim_tr_reg[1:100, ]) %>%
-      step_discretize_xgb(all_predictors(), outcome = "y") %>%
+      recipe(y ~ ., data = sim_tr_reg[1:100, ]) |>
+      step_discretize_xgb(all_predictors(), outcome = "y") |>
       prep()
   })
 
@@ -471,16 +485,16 @@ test_that("step_discretize_xgb for regression", {
     "Neighborhood"
   )
 
-  xgb_rec <- ames_data_train %>%
-    select(Sale_Price, one_of(predictors_non_numeric)) %>%
-    recipe(Sale_Price ~ .) %>%
-    step_medianimpute(all_numeric()) %>%
+  xgb_rec <- ames_data_train |>
+    select(Sale_Price, one_of(predictors_non_numeric)) |>
+    recipe(Sale_Price ~ .) |>
+    step_medianimpute(all_numeric()) |>
     step_discretize_xgb(all_predictors(), outcome = "Sale_Price")
 })
 
 test_that("xgb_binning() errors if only one class in outcome", {
-  skip_on_cran() # because data.table uses all cores by default 
-  
+  skip_on_cran() # because data.table uses all cores by default
+
   const_outcome <- data.frame(
     outcome = factor(rep("a", 1000)),
     predictor = rep(1, 1000)
@@ -501,22 +515,22 @@ test_that("xgb_binning() errors if only one class in outcome", {
 })
 
 test_that("case weights step_discretize_xgb", {
-  skip_on_cran() # because data.table uses all cores by default 
-  
-  sim_tr_cls_cw <- sim_tr_cls %>%
+  skip_on_cran() # because data.table uses all cores by default
+
+  sim_tr_cls_cw <- sim_tr_cls |>
     mutate(weight = importance_weights(rep(1:0, each = 500)))
 
-  sim_tr_mcls_cw <- sim_tr_mcls %>%
+  sim_tr_mcls_cw <- sim_tr_mcls |>
     mutate(weight = importance_weights(rep(1:0, each = 500)))
 
-  sim_tr_reg_cw <- sim_tr_reg %>%
+  sim_tr_reg_cw <- sim_tr_reg |>
     mutate(weight = importance_weights(rep(1:0, each = 500)))
 
   # classification ------------------------------------------------------------
   set.seed(125)
   # General use
   xgb_rec_cw <-
-    recipe(class ~ ., data = sim_tr_cls_cw) %>%
+    recipe(class ~ ., data = sim_tr_cls_cw) |>
     step_discretize_xgb(all_predictors(), outcome = "class")
 
   set.seed(28)
@@ -527,7 +541,7 @@ test_that("case weights step_discretize_xgb", {
   set.seed(28)
   for (col_names in c("x", "z")) {
     exp_rules[[col_names]] <- xgb_binning(
-      sim_tr_cls_cw %>% select(-weight),
+      sim_tr_cls_cw |> select(-weight),
       "class",
       col_names,
       sample_val = 0.20,
@@ -547,7 +561,7 @@ test_that("case weights step_discretize_xgb", {
   set.seed(125)
   # General use
   xgb_rec_cw <-
-    recipe(class ~ ., data = sim_tr_mcls_cw) %>%
+    recipe(class ~ ., data = sim_tr_mcls_cw) |>
     step_discretize_xgb(all_predictors(), outcome = "class")
 
   set.seed(28)
@@ -558,7 +572,7 @@ test_that("case weights step_discretize_xgb", {
   set.seed(28)
   for (col_names in c("x", "z")) {
     exp_rules[[col_names]] <- xgb_binning(
-      sim_tr_mcls_cw %>% select(-weight),
+      sim_tr_mcls_cw |> select(-weight),
       "class",
       col_names,
       sample_val = 0.20,
@@ -578,7 +592,7 @@ test_that("case weights step_discretize_xgb", {
   set.seed(125)
   # General use
   xgb_rec_cw <-
-    recipe(y ~ ., data = sim_tr_reg_cw) %>%
+    recipe(y ~ ., data = sim_tr_reg_cw) |>
     step_discretize_xgb(all_predictors(), outcome = "y")
 
   set.seed(28)
@@ -589,7 +603,7 @@ test_that("case weights step_discretize_xgb", {
   set.seed(28)
   for (col_names in c("x", "z")) {
     exp_rules[[col_names]] <- xgb_binning(
-      sim_tr_reg_cw %>% select(-weight),
+      sim_tr_reg_cw |> select(-weight),
       "y",
       col_names,
       sample_val = 0.20,
@@ -611,11 +625,11 @@ test_that("case weights step_discretize_xgb", {
 
 test_that("tunable", {
   rec <-
-    recipe(~., data = mtcars) %>%
+    recipe(~., data = mtcars) |>
     step_discretize_xgb(all_predictors(), outcome = "mpg")
   rec_param <- tunable.step_discretize_xgb(rec$steps[[1]])
   expect_equal(
-    rec_param$name, 
+    rec_param$name,
     c("sample_val", "learn_rate", "num_breaks", "tree_depth", "min_n")
   )
   expect_true(all(rec_param$source == "recipe"))
@@ -631,47 +645,46 @@ test_that("tunable", {
 test_that("bad args", {
   expect_snapshot(
     error = TRUE,
-    recipe(~., data = mtcars) %>%
-      step_discretize_xgb(outcome = "class", sample_val = -4) %>%
+    recipe(~., data = mtcars) |>
+      step_discretize_xgb(outcome = "class", sample_val = -4) |>
       prep()
   )
   expect_snapshot(
     error = TRUE,
-    recipe(~., data = mtcars) %>%
-      step_discretize_xgb(outcome = "class", learn_rate = -4) %>%
+    recipe(~., data = mtcars) |>
+      step_discretize_xgb(outcome = "class", learn_rate = -4) |>
       prep()
   )
   expect_snapshot(
     error = TRUE,
-    recipe(~., data = mtcars) %>%
-      step_discretize_xgb(outcome = "class", num_breaks = -4) %>%
+    recipe(~., data = mtcars) |>
+      step_discretize_xgb(outcome = "class", num_breaks = -4) |>
       prep()
   )
   expect_snapshot(
     error = TRUE,
-    recipe(~., data = mtcars) %>%
-      step_discretize_xgb(outcome = "class", tree_depth = -4) %>%
+    recipe(~., data = mtcars) |>
+      step_discretize_xgb(outcome = "class", tree_depth = -4) |>
       prep()
   )
   expect_snapshot(
     error = TRUE,
-    recipe(~., data = mtcars) %>%
-      step_discretize_xgb(outcome = "class", min_n = -4) %>%
+    recipe(~., data = mtcars) |>
+      step_discretize_xgb(outcome = "class", min_n = -4) |>
       prep()
   )
-
 })
 
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
-  rec <- recipe(class ~ ., data = sim_tr_cls) %>%
-    step_discretize_xgb(x, z, outcome = "class") %>%
-    update_role(x, new_role = "potato") %>%
+  rec <- recipe(class ~ ., data = sim_tr_cls) |>
+    step_discretize_xgb(x, z, outcome = "class") |>
+    update_role(x, new_role = "potato") |>
     update_role_requirements(role = "potato", bake = FALSE)
-  
+
   rec_trained <- prep(rec, training = sim_tr_cls, verbose = FALSE)
-  
+
   expect_snapshot(
     error = TRUE,
     bake(rec_trained, new_data = sim_tr_cls[, -1])
@@ -681,53 +694,53 @@ test_that("bake method errors when needed non-standard role columns are missing"
 test_that("empty printing", {
   rec <- recipe(mpg ~ ., mtcars)
   rec <- step_discretize_xgb(rec, outcome = "mpg")
-  
+
   expect_snapshot(rec)
-  
+
   rec <- prep(rec, mtcars)
-  
+
   expect_snapshot(rec)
 })
 
 test_that("empty selection prep/bake is a no-op", {
   rec1 <- recipe(mpg ~ ., mtcars)
   rec2 <- step_discretize_xgb(rec1, outcome = "mpg")
-  
+
   rec1 <- prep(rec1, mtcars)
   rec2 <- prep(rec2, mtcars)
-  
+
   baked1 <- bake(rec1, mtcars)
   baked2 <- bake(rec2, mtcars)
-  
+
   expect_identical(baked1, baked2)
 })
 
 test_that("empty selection tidy method works", {
   rec <- recipe(mpg ~ ., mtcars)
   rec <- step_discretize_xgb(rec, outcome = "mpg")
-  
+
   expect <- tibble(terms = character(), value = double(), id = character())
-  
+
   expect_identical(tidy(rec, number = 1), expect)
-  
+
   rec <- prep(rec, mtcars)
-  
+
   expect_identical(tidy(rec, number = 1), expect)
 })
 
 test_that("printing", {
-  skip_on_cran() # because data.table uses all cores by default 
-  
-  rec <- recipe(class ~ ., data = sim_tr_cls) %>%
+  skip_on_cran() # because data.table uses all cores by default
+
+  rec <- recipe(class ~ ., data = sim_tr_cls) |>
     step_discretize_xgb(all_predictors(), outcome = "class")
-  
+
   expect_snapshot(print(rec))
   expect_snapshot(prep(rec))
 })
 
 test_that("tunable is setup to works with extract_parameter_set_dials", {
   skip_if_not_installed("dials")
-  rec <- recipe(~., data = mtcars) %>%
+  rec <- recipe(~., data = mtcars) |>
     step_discretize_xgb(
       all_predictors(),
       outcome = "mpg",
@@ -737,9 +750,9 @@ test_that("tunable is setup to works with extract_parameter_set_dials", {
       tree_depth = hardhat::tune(),
       min_n = hardhat::tune()
     )
-  
+
   params <- extract_parameter_set_dials(rec)
-  
+
   expect_s3_class(params, "parameters")
   expect_identical(nrow(params), 5L)
 })
