@@ -9,20 +9,23 @@ omit_warning <- function(pattern) {
   }
 }
 
-test_that("factor encoded predictor", {
+test_that("factor outcome - factor predictor", {
   skip_on_cran()
   skip_if_not_installed("rstanarm")
   skip_if_not_installed("Matrix", "1.6-2")
 
   expect_snapshot(
-    transform = omit_warning("^(The largest R-hat is|Bulk Effective|Tail Effective)"),
+    transform = omit_warning(
+      "^(The largest R-hat is|Bulk Effective|Tail Effective)"
+    ),
     {
-      class_test <- recipe(x2 ~ ., data = ex_dat) %>%
-        step_lencode_bayes(x3,
+      class_test <- recipe(x2 ~ ., data = ex_dat) |>
+        step_lencode_bayes(
+          x3,
           outcome = vars(x2),
           verbose = FALSE,
           options = opts
-        ) %>%
+        ) |>
         prep(training = ex_dat, retain = TRUE)
     }
   )
@@ -79,22 +82,26 @@ test_that("factor encoded predictor", {
   )
 })
 
-test_that("character encoded predictor", {
+test_that("factor outcome - character predictor", {
   skip_on_cran()
   skip_if_not_installed("rstanarm")
   skip_if_not_installed("Matrix", "1.6-2")
-  
+
   expect_snapshot(
-    transform = omit_warning("^(The largest R-hat is|Bulk Effective|Tail Effective)"),
-    class_test <- recipe(x2 ~ ., data = ex_dat_ch) %>%
-      step_lencode_bayes(x3,
+    transform = omit_warning(
+      "^(The largest R-hat is|Bulk Effective|Tail Effective)"
+    ),
+    class_test <- recipe(x2 ~ ., data = ex_dat_ch) |>
+      step_lencode_bayes(
+        x3,
         outcome = vars(x2),
         verbose = FALSE,
         options = opts,
         id = "id"
-      ) %>%
+      ) |>
       prep(
-        training = ex_dat_ch, retain = TRUE,
+        training = ex_dat_ch,
+        retain = TRUE,
         options = opts
       )
   )
@@ -149,21 +156,24 @@ test_that("character encoded predictor", {
   )
 })
 
-test_that("factor encoded predictor", {
+test_that("numeric outcome - factor predictor", {
   skip_on_cran()
   skip_if_not_installed("rstanarm")
   skip_if_not_installed("Matrix", "1.6-2")
-  
+
   expect_snapshot(
-    transform = omit_warning("^(The largest R-hat is|Bulk Effective|Tail Effective)"),
+    transform = omit_warning(
+      "^(The largest R-hat is|Bulk Effective|Tail Effective)"
+    ),
     {
       set.seed(8283)
-      reg_test <- recipe(x1 ~ ., data = ex_dat) %>%
-        step_lencode_bayes(x3,
+      reg_test <- recipe(x1 ~ ., data = ex_dat) |>
+        step_lencode_bayes(
+          x3,
           outcome = vars(x1),
           verbose = FALSE,
           options = opts
-        ) %>%
+        ) |>
         prep(training = ex_dat, retain = TRUE)
     }
   )
@@ -222,21 +232,24 @@ test_that("factor encoded predictor", {
   )
 })
 
-test_that("character encoded predictor", {
+test_that("numeric outcome - character predictor", {
   skip_on_cran()
   skip_if_not_installed("rstanarm")
   skip_if_not_installed("Matrix", "1.6-2")
-  
+
   expect_snapshot(
-    transform = omit_warning("^(The largest R-hat is|Bulk Effective|Tail Effective)"),
+    transform = omit_warning(
+      "^(The largest R-hat is|Bulk Effective|Tail Effective)"
+    ),
     {
       set.seed(8283)
-      reg_test <- recipe(x1 ~ ., data = ex_dat_ch) %>%
-        step_lencode_bayes(x3,
+      reg_test <- recipe(x1 ~ ., data = ex_dat_ch) |>
+        step_lencode_bayes(
+          x3,
           outcome = vars(x1),
           verbose = FALSE,
           options = opts
-        ) %>%
+        ) |>
         prep(training = ex_dat_ch, retain = TRUE)
     }
   )
@@ -297,18 +310,19 @@ test_that("Works with passing family ", {
   skip_if_not_installed("rstanarm")
   skip_if_not_installed("Matrix", "1.6-2")
 
-  ex_dat_poisson <- ex_dat %>%
+  ex_dat_poisson <- ex_dat |>
     mutate(outcome = rpois(n(), 5))
 
   expect_snapshot(
     transform = omit_warning("^(Bulk Effective|Tail Effective)"),
     {
-      class_test <- recipe(outcome ~ ., data = ex_dat_poisson) %>%
-        step_lencode_bayes(x3,
+      class_test <- recipe(outcome ~ ., data = ex_dat_poisson) |>
+        step_lencode_bayes(
+          x3,
           outcome = vars(outcome),
           verbose = FALSE,
           options = c(opts, family = stats::poisson)
-        ) %>%
+        ) |>
         prep(training = ex_dat_poisson, retain = TRUE)
     }
   )
@@ -372,24 +386,25 @@ test_that("case weights", {
 
   wts_int <- rep(c(0, 1), times = c(100, 400))
 
-  ex_dat_cw <- ex_dat %>%
+  ex_dat_cw <- ex_dat |>
     mutate(wts = importance_weights(wts_int))
 
   expect_snapshot(
     transform = omit_warning("^^(Bulk Effective|Tail Effective|The largest)"),
     {
-      class_test <- recipe(x2 ~ ., data = ex_dat_cw) %>%
-        step_lencode_bayes(x3,
+      class_test <- recipe(x2 ~ ., data = ex_dat_cw) |>
+        step_lencode_bayes(
+          x3,
           outcome = vars(x2),
           verbose = FALSE,
           options = opts
-        ) %>%
+        ) |>
         prep(training = ex_dat_cw, retain = TRUE)
 
       junk <- capture.output(
         ref_mod <- rstanarm::stan_glmer(
           formula = x2 ~ (1 | value),
-          data = ex_dat_cw %>% transmute(value = x3, x2),
+          data = ex_dat_cw |> transmute(value = x3, x2),
           family = binomial(),
           na.action = na.omit,
           seed = 34677,
@@ -412,7 +427,7 @@ test_that("case weights", {
 test_that("bad args", {
   expect_snapshot(
     error = TRUE,
-    recipe(~., data = mtcars) %>%
+    recipe(~., data = mtcars) |>
       step_lencode_bayes(outcome = vars(mpg), verbose = "yes")
   )
 })
@@ -422,14 +437,14 @@ test_that("bad args", {
 test_that("bake method errors when needed non-standard role columns are missing", {
   skip_if_not_installed("rstanarm")
   skip_if_not_installed("Matrix", "1.6-2")
-  
-  rec <- recipe(x2 ~ ., data = ex_dat) %>%
-    step_lencode_bayes(x3, outcome = vars(x2)) %>%
-    update_role(x3, new_role = "potato") %>%
+
+  rec <- recipe(x2 ~ ., data = ex_dat) |>
+    step_lencode_bayes(x3, outcome = vars(x2)) |>
+    update_role(x3, new_role = "potato") |>
     update_role_requirements(role = "potato", bake = FALSE)
-  
+
   rec_trained <- prep(rec, training = ex_dat, verbose = FALSE)
-  
+
   expect_snapshot(
     error = TRUE,
     bake(rec_trained, new_data = ex_dat[, -3])
@@ -439,56 +454,52 @@ test_that("bake method errors when needed non-standard role columns are missing"
 test_that("empty printing", {
   rec <- recipe(mpg ~ ., mtcars)
   rec <- step_lencode_bayes(rec, outcome = vars(mpg))
-  
+
   expect_snapshot(rec)
-  
+
   rec <- prep(rec, mtcars)
-  
+
   expect_snapshot(rec)
 })
 
 test_that("empty selection prep/bake is a no-op", {
   rec1 <- recipe(mpg ~ ., mtcars)
   rec2 <- step_lencode_bayes(rec1, outcome = vars(mpg))
-  
+
   rec1 <- prep(rec1, mtcars)
   rec2 <- prep(rec2, mtcars)
-  
+
   baked1 <- bake(rec1, mtcars)
   baked2 <- bake(rec2, mtcars)
-  
+
   expect_identical(baked1, baked2)
 })
 
 test_that("empty selection tidy method works", {
   rec <- recipe(mpg ~ ., mtcars)
   rec <- step_lencode_bayes(rec, outcome = vars(mpg))
-  
+
   expect <- tibble(
     terms = character(),
     level = character(),
     value = double(),
     id = character()
   )
-  
+
   expect_identical(tidy(rec, number = 1), expect)
-  
+
   rec <- prep(rec, mtcars)
-  
+
   expect_identical(tidy(rec, number = 1), expect)
 })
 
 test_that("printing", {
   skip_if_not_installed("rstanarm")
   skip_if_not_installed("Matrix", "1.6-2")
-  
-  rec <- recipe(x2 ~ ., data = ex_dat) %>%
-    step_lencode_bayes(x3,
-                       outcome = vars(x2),
-                       verbose = FALSE,
-                       options = opts
-    )
-  
+
+  rec <- recipe(x2 ~ ., data = ex_dat) |>
+    step_lencode_bayes(x3, outcome = vars(x2), verbose = FALSE, options = opts)
+
   expect_snapshot(print(rec))
   expect_snapshot(
     prep(rec),
